* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Apptio Integration](https://help.sap.com/docs/leanix/ea/apptio-integration)
  * Apptio Technical Overview
